# Example Package

[GetHub Project](https://github.com/DrSudoSaeed/)

This is a movie search library.

This library is always updated. Wait for new versions soon!

To use, install the library according to the instructions!

**Follow the steps below to use:**

```

from searchfilms import search_film

search_film("fast")  # Replace the movie name with fast

```